from __future__ import absolute_import
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,platform
import tests.CheckEscUnesc

from filesysobjects.FileSysObjects import normpathX
#
#######################
#


class CallUnits(tests.CheckEscUnesc.CheckEscUnesc):

    def testCase040(self):
        _in        = r'smb://'
        _esc     = r'smb://'
        _unesc = r'smb://'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase050(self):
        _in        = r'smb://smb_browse/'
        _esc     = r'smb://smb_browse'
        _unesc = r'smb://smb_browse'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase060(self):
        _in        = r'smb://smb_server/'
        _esc     = r'smb://smb_server'
        _unesc = r'smb://smb_server'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase070(self):
        _in        = r'smb://smb_server/abs_path'
        if platform.system() == 'Windows':
            _esc     = r'smb://smb_server\\abs_path'
            _unesc = r'smb://smb_server\abs_path'
        else:
            _esc     = r'smb://smb_server/abs_path'
            _unesc = r'smb://smb_server/abs_path'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase080(self):
        _in        = r'smb://netbios.scope.id/'
        _esc     = r'smb://netbios.scope.id'
        _unesc = r'smb://netbios.scope.id'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase090(self):
        _in        = r'smb://netbios/?SCOPE=scope.id'
        if platform.system() == 'Windows':
            _esc     = r'smb://netbios\\?SCOPE=scope.id'
            _unesc = r'smb://netbios\?SCOPE=scope.id'
        else:
            _esc     = r'smb://netbios/?SCOPE=scope.id'
            _unesc = r'smb://netbios/?SCOPE=scope.id'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase100(self):
        _in        = r'smb://jcifs/?CALLED=VIRTSERV;NBNS=172.24.19.18'
        if platform.system() == 'Windows':
            _esc     = r'smb://jcifs\\?CALLED=VIRTSERV;NBNS=172.24.19.18'
            _unesc = r'smb://jcifs\?CALLED=VIRTSERV;NBNS=172.24.19.18'
        else:
            _esc     = r'smb://jcifs/?CALLED=VIRTSERV;NBNS=172.24.19.18'
            _unesc = r'smb://jcifs/?CALLED=VIRTSERV;NBNS=172.24.19.18'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase110(self):
        _in        = r'smb://smedley/?NBNS=172.24.19.18;NODETYPE=H'
        if platform.system() == 'Windows':
            _esc     = r'smb://smedley\\?NBNS=172.24.19.18;NODETYPE=H'
            _unesc = r'smb://smedley\?NBNS=172.24.19.18;NODETYPE=H'
        else:
            _esc     = r'smb://smedley/?NBNS=172.24.19.18;NODETYPE=H'
            _unesc = r'smb://smedley/?NBNS=172.24.19.18;NODETYPE=H'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase120(self):
        _in        = r'smb://corgis/?NODETYPE=B'
        if platform.system() == 'Windows':
            _esc     = r'smb://corgis\\?NODETYPE=B'
            _unesc = r'smb://corgis\?NODETYPE=B'
        else:
            _esc     = r'smb://corgis/?NODETYPE=B'
            _unesc = r'smb://corgis/?NODETYPE=B'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase130(self):
        _in        = r'smb://jcifs.samba.org/?NODETYPE=;CALLED=SMBSERV'
        if platform.system() == 'Windows':
            _esc     = r'smb://jcifs.samba.org\\?NODETYPE=;CALLED=SMBSERV'
            _unesc = r'smb://jcifs.samba.org\?NODETYPE=;CALLED=SMBSERV'
        else:
            _esc     = r'smb://jcifs.samba.org/?NODETYPE=;CALLED=SMBSERV'
            _unesc = r'smb://jcifs.samba.org/?NODETYPE=;CALLED=SMBSERV'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase140(self):
        _in        = r'smb://bran/SCOPE='
        if platform.system() == 'Windows':
            _esc     = r'smb://bran\\SCOPE='
            _unesc = r'smb://bran\SCOPE='
        else:
            _esc     = r'smb://bran/SCOPE='
            _unesc = r'smb://bran/SCOPE='
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase150(self):
        _in        = r'smb://marika/SCOPE=;NODETYPE=B'
        if platform.system() == 'Windows':
            _esc     = r'smb://marika\\SCOPE=;NODETYPE=B'
            _unesc = r'smb://marika\SCOPE=;NODETYPE=B'
        else:
            _esc     = r'smb://marika/SCOPE=;NODETYPE=B'
            _unesc = r'smb://marika/SCOPE=;NODETYPE=B'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase160(self):
        _in        = r'//Specifying a drive and a file name'
        if platform.system() == 'Windows':
            _esc     = r'\\\\Specifying a drive and a file name'
            _unesc = r'\\Specifying a drive and a file name'
        else:
            _esc     = r'//Specifying a drive and a file name'
            _unesc = r'//Specifying a drive and a file name'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase170(self):
        _in        = r'file:///C|/My Documents/ALetter.html'
        if platform.system() == 'Windows':
            _esc     = r'file://\\C|\\My Documents\\ALetter.html'
            _unesc = r'file://\C|\My Documents\ALetter.html'
        else:
            _esc     = r'file:///C|/My Documents/ALetter.html'
            _unesc = r'file:///C|/My Documents/ALetter.html'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase180(self):
        _in        = r'//Specifying only a drive and a path to browse the directory'
        if platform.system() == 'Windows':
            _esc     = r'\\\\Specifying only a drive and a path to browse the directory'
            _unesc = r'\\Specifying only a drive and a path to browse the directory'
        else:
            _esc     = r'//Specifying only a drive and a path to browse the directory'
            _unesc = r'//Specifying only a drive and a path to browse the directory'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase190(self):
        _in        = r'file:///C|/My Documents/'
        if platform.system() == 'Windows':
            _esc     = r'file://\\C|\\My Documents'
            _unesc = r'file://\C|\My Documents'
        else:
            _esc     = r'file:///C|/My Documents'
            _unesc = r'file:///C|/My Documents'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase200(self):
        _in        = 'C:\My Documents\\'
        if platform.system() == 'Windows':
            _esc     = r'C:\\My Documents'
            _unesc = r'C:\My Documents'
        else:
            _esc     = r'C:/My Documents'
            _unesc = r'C:/My Documents'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase210(self):
        _in        = '\My Documents\\'
        _esc     = r'\\My Documents'
        _unesc = r'\My Documents'
        self.check_esc_unesc(_in,_esc,_unesc, 'b')
 
    def testCase220(self):
        _in        = r'file:///Users/User/2ndFile.html'
        if platform.system() == 'Windows':
            _esc     = r'file://\\Users\\User\\2ndFile.html'
            _unesc = r'file://\Users\User\2ndFile.html'
        else:
            _esc     = r'file:///Users/User/2ndFile.html'
            _unesc = r'file:///Users/User/2ndFile.html'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase230(self):
        _in        = r'file:///C:/Users/User/2ndFile.html'
        if platform.system() == 'Windows':
            _esc     = r'file://\\C:\\Users\\User\\2ndFile.html'
            _unesc = r'file://\C:\Users\User\2ndFile.html'
        else:
            _esc     = r'file:///C:/Users/User/2ndFile.html'
            _unesc = r'file:///C:/Users/User/2ndFile.html'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase240(self):
        _in        = r'file://alpha.hut.fi/u/lai/tik/tik76002/public_html/lerman.files/chaps'
        if platform.system() == 'Windows':
            _esc     = r'file://alpha.hut.fi\\u\\lai\\tik\\tik76002\\public_html\\lerman.files\\chaps'
            _unesc = r'file://alpha.hut.fi\u\lai\tik\tik76002\public_html\lerman.files\chaps'
        else:
            _esc     = r'file://alpha.hut.fi/u/lai/tik/tik76002/public_html/lerman.files/chaps'
            _unesc = r'file://alpha.hut.fi/u/lai/tik/tik76002/public_html/lerman.files/chaps'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase250(self):
        _in        = r'file:///u/lai/tik/tik76002/public_html/lerman.files/chaps'
        if platform.system() == 'Windows':
            _esc     = r'file://\\u\\lai\\tik\\tik76002\\public_html\\lerman.files\\chaps'
            _unesc = r'file://\u\lai\tik\tik76002\public_html\lerman.files\chaps'
        else:
            _esc     = r'file:///u/lai/tik/tik76002/public_html/lerman.files/chaps'
            _unesc = r'file:///u/lai/tik/tik76002/public_html/lerman.files/chaps'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase260(self):
        _in        = r'file:///etc/motd'
        if platform.system() == 'Windows':
            _esc     = r'file://\\etc\\motd'
            _unesc = r'file://\etc\motd'
        else:
            _esc     = r'file:///etc/motd'
            _unesc = r'file:///etc/motd'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase270(self):
        _in        = r'file://localhost/absolute/path/to/file'
        if platform.system() == 'Windows':
            _esc     = r'file://localhost\\absolute\\path\\to\\file'
            _unesc = r'file://localhost\absolute\path\to\file'
        else:
            _esc     = r'file://localhost/absolute/path/to/file'
            _unesc = r'file://localhost/absolute/path/to/file'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase280(self):
        _in        = r'file://file_at_current_dir'
        _esc     = r'file://file_at_current_dir'
        _unesc = r'file://file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase290(self):
        _in        = r'file:///./file_at_current_dir'
        if platform.system() == 'Windows':
            _esc     = r'file://\\file_at_current_dir'
            _unesc = r'file://\file_at_current_dir'
        else:
            _esc     = r'file:///file_at_current_dir'
            _unesc = r'file:///file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase300(self):
        _in        = r'file:///foo.txt'
        if platform.system() == 'Windows':
            _esc     = r'file://\\foo.txt'
            _unesc = r'file://\foo.txt'
        else:
            _esc     = r'file:///foo.txt'
            _unesc = r'file:///foo.txt'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase310(self):
        _in        = r'file://foo.txt'
        _esc     = r'file://foo.txt'
        _unesc = r'file://foo.txt'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase320(self):
        _in        = r'file:///C:/autoexec.bat'
        if platform.system() == 'Windows':
            _esc     = r'file://\\C:\\autoexec.bat'
            _unesc = r'file://\C:\autoexec.bat'
        else:
            _esc     = r'file:///C:/autoexec.bat'
            _unesc = r'file:///C:/autoexec.bat'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase330(self):
        _in        = r'file:///C%3A/autoexec.bat'
        if platform.system() == 'Windows':
            _esc     = r'file://\\C%3A\\autoexec.bat'
            _unesc = r'file://\C%3A\autoexec.bat'
        else:
            _esc     = r'file:///C%3A/autoexec.bat'
            _unesc = r'file:///C%3A/autoexec.bat'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase340(self):
        _in        = r'smb://domain;username:passwor]@server/share/path'
        if platform.system() == 'Windows':
            _esc     = r'smb://domain;username:passwor]@server\\share\\path'
            _unesc = r'smb://domain;username:passwor]@server\share\path'
        else:
            _esc     = r'smb://domain;username:passwor]@server/share/path'
            _unesc = r'smb://domain;username:passwor]@server/share/path'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase350(self):
        _in        = r'smb://authdomain;user@host:port/share/dirpath/name?context'
        if platform.system() == 'Windows':
            _esc     = r'smb://authdomain;user@host:port\\share\\dirpath\\name?context'
            _unesc = r'smb://authdomain;user@host:port\share\dirpath\name?context'
        else:
            _esc     = r'smb://authdomain;user@host:port/share/dirpath/name?context'
            _unesc = r'smb://authdomain;user@host:port/share/dirpath/name?context'
        self.check_esc_unesc(_in,_esc,_unesc)


#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Check IEEE1003.1-Chap. 4.2.
"""
from __future__ import absolute_import

import unittest
import os,sys
import platform

from pysourceinfo.PySourceInfo import getPythonPathRel,getPythonPathFromSysPath
from filesysobjects.FileSysObjects import setUpperTreeSearchPath,FileSysObjectsException,splitAppPrefix,getAppPrefixLocalPath,getTopFromPathString,unescapeFilePath
from unittest.case import SkipTest


#
#######################
#
class CallUnits(unittest.TestCase):
    
    def testCase_file_uri(self):
        
        _s = sys.path[:]

        start0 = os.path.abspath(os.path.dirname(__file__)+os.sep+os.path.normpath('/a/b/c'))
    
        # normalize
        _start_elems = splitAppPrefix(start0)
        start= getAppPrefixLocalPath(_start_elems)

        assert start0 == start

        top = 'file://'+os.path.splitdrive(os.path.abspath(os.path.dirname(__file__)))[1]

        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'ias':True}) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        myplist = [getTopFromPathString('AppPathSyntax',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 

        resx = [
            'file/file_uri/a/b/c', 
            'file/file_uri/a/b', 
            'file/file_uri/a', 
            'file/file_uri'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass

    def file_multiple_uri(self):

        if platform.system() != 'Windows':
            unittest.SkipTest("Requires Windows - skipped!")
            return True
       
        _s = sys.path[:]

        _share,start = os.path.splitdrive(os.path.abspath(os.path.dirname(__file__))+os.path.normpath('/a/b/c'))
        _share,top = os.path.splitdrive(os.path.abspath(os.path.dirname(__file__))+os.path.normpath('/a'))
        top = 'file://'+top
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'ias':True}) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        myplist = [getTopFromPathString('AppPathSyntax',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 

        resx = [
            'file/file_uri/a/b/c', 
            'file/file_uri/a/b', 
            'file/file_uri/a', 
            'file/file_uri'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        assert resx == res
        pass

    def file_app(self):
        apstr = 'file://///'+os.path.normpath('hostname/share/a/b/c')
        retRef = ('SHARE','hostname', 'share', os.path.normpath('a/b/c')) 
        ret = splitAppPrefix(apstr)
        self.assertEqual(retRef, ret) 


if __name__ == '__main__':
    unittest.main()



"""Find a matching relative filepathname in upper directory tree.

Calling elementary functions.

* **Data**:
  ::
  
    see 'testdata.examples'
  
* **Call**:
  ::

    import testdata
    import filesysobjects.FileSysObjects
      
    s = os.sep
    any_sub_path = os.path.normpath('a/b0/c/d/D.txt')

    spath  = testdata.mypath
    spath += any_sub_path

    _plist = []

    setUpperTreeSearchPath(spath,os.path.normpath('b/B.txt'), _plist)
    rp = findRelPathInSearchPath(spath,_plist)
    
* **Result**:
  ::

    expected = os.path.normpath(testdata.mypath +s+ 'a/b/B.txt')

"""
from __future__ import absolute_import
from __future__ import print_function
import filesysobjects

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath
from filesysobjects.FileSysObjects import findRelPathInSearchPath
from filesysobjects.FileSysObjects import findRelPathInUpperTree
from filesysobjects.FileSysObjects import clearPath
from pysourceinfo.PySourceInfo import getPythonPathRel

#
#######################
#

class CallUnits(unittest.TestCase):
    
    def testCase000(self):
        _s = sys.path[:]

        import testdata
        import filesysobjects.FileSysObjects
          
        s = os.sep
        
        # start of upward search - file is converted into it's containing directory node
        any_sub_path = os.path.normpath('a/b0/c')
        spath  = testdata.mypath
        spath += s+ any_sub_path
        
        # store new search list, here without required sys.path
        _plist = []


        # 0. build a search path list - if not yet available
        #    adds each directory from spath to its matching 
        #    subnode  "a/b"
        #
        setUpperTreeSearchPath(spath,os.path.normpath('a/b0'), _plist)
        
        # 1. make it canonical - optional
        clearPath(_plist)
        
        # 2. find the requested entry
        rp = findRelPathInSearchPath(spath,_plist)

        expected = os.path.normpath(testdata.mypath +s+ 'a/b0/c')
        assert rp == expected
    
#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os
import platform
import tests.CheckEscUnesc

from filesysobjects.FileSysObjects import normpathX
#
#######################
#


class CallUnits(tests.CheckEscUnesc.CheckEscUnesc):

    def testCase010(self):
        _in        = r'\\host\share'
        _esc     = r'\\\\host\\share'
        _unesc = r'\\host\share'
        self.check_esc_unesc(_in,_esc,_unesc,'b')
        
    def testCase010a(self):
        _in        = r'smb://host/share'
        if platform.system() == 'Windows':
            _esc     = r'smb://host\\share'
            _unesc = r'smb://host\share'
        else:
            _esc     = r'smb://host/share'
            _unesc = r'smb://host/share'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase020(self):
        _in        = '\\\\host\share\dirpath'
        if platform.system() == 'Windows':
            _esc     = r'\\\\host\\share\\dirpath'
            _unesc = r'\\host\share\dirpath'
        else:
            _esc     = r'//host/share/dirpath'
            _unesc = r'//host/share/dirpath'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase020a(self):
        _in        = 'smb://host/share/dirpath'
        if platform.system() == 'Windows':
            _esc     = r'smb://host\\share\\dirpath'
            _unesc = r'smb://host\share\dirpath'
        else:
            _esc     = r'smb://host/share/dirpath'
            _unesc = r'smb://host/share/dirpath'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase030(self):
        _in        = '\\\\host\share\dirpath\filename'
        if platform.system() == 'Windows':
            _esc     = r'\\\\host\\share\\dirpath\\filename'
            _unesc = r'\\host\share\dirpath\filename'
        else:
            _esc     = r'//host/share/dirpath/filename'
            _unesc = r'//host/share/dirpath/filename'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase030a(self):
        _in        = r'smb://host/share/dirpath/filename'
        if platform.system() == 'Windows':
            _esc     = r'smb://host\\share\\dirpath\\filename'
            _unesc = r'smb://host\share\dirpath\filename'
        else:
            _esc     = r'smb://host/share/dirpath/filename'
            _unesc = r'smb://host/share/dirpath/filename'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase040(self):
        _in        = r'smb://host/share/'
        if platform.system() == 'Windows':
            _esc     = r'smb://host\\share'
            _unesc = r'smb://host\share'
        else:
            _esc     = r'smb://host/share'
            _unesc = r'smb://host/share'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase050(self):
        _in        = r'smb://host/share/dirpath'
        if platform.system() == 'Windows':
            _esc     = r'smb://host\\share\\dirpath'
            _unesc = r'smb://host\share\dirpath'
        else:
            _esc     = r'smb://host/share/dirpath'
            _unesc = r'smb://host/share/dirpath'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase060(self):
        _in        = r'smb://host/share/name'
        if platform.system() == 'Windows':
            _esc     = r'smb://host\\share\\name'
            _unesc = r'smb://host\share\name'
        else:
            _esc     = r'smb://host/share/name'
            _unesc = r'smb://host/share/name'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase070(self):
        _in        = r'smb://host/share/dirpath/name'
        if platform.system() == 'Windows':
            _esc     = r'smb://host\\share\\dirpath\\name'
            _unesc = r'smb://host\share\dirpath\name'
        else:
            _esc     = r'smb://host/share/dirpath/name'
            _unesc = r'smb://host/share/dirpath/name'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase080(self):
        _in        = r'smb://WORKGROUP@host/share'
        if platform.system() == 'Windows':
            _esc     = r'smb://WORKGROUP@host\\share'
            _unesc = r'smb://WORKGROUP@host\share'
        else:
            _esc     = r'smb://WORKGROUP@host/share'
            _unesc = r'smb://WORKGROUP@host/share'
        self.check_esc_unesc(_in,_esc,_unesc)

    def testCase090(self):
        _in        = r'smb://WORKGROUP;User@host/share'
        if platform.system() == 'Windows':
            _esc     = r'smb://WORKGROUP;User@host\\share'
            _unesc = r'smb://WORKGROUP;User@host\share'
        else:
            _esc     = r'smb://WORKGROUP;User@host/share'
            _unesc = r'smb://WORKGROUP;User@host/share'
        self.check_esc_unesc(_in,_esc,_unesc)
#
#######################
#

if __name__ == '__main__':
    unittest.main()



"""Test PyUnit environment. This is a required call-dummy only.
"""
from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2015-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.0'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

import unittest
if __name__ == '__main__':
    unittest.main()
    
class UseCase(unittest.TestCase):
    pass

class TestCase(unittest.TestCase):
    pass



from __future__ import absolute_import

import unittest
import os

from filesysobjects.FileSysObjects import setUpperTreeSearchPath,addPathToSearchPath


#
#######################
#
class CallUnits(unittest.TestCase):
    name=os.path.curdir+__file__

    output=True
    output=False

    #
    # Create by object
    #
    def testCase000(self):
        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        start = None
        top = None
        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        addPathToSearchPath(os.path.dirname(os.path.dirname(__file__)+os.sep+C), res,**{'append':True})
        
        resx = [
            os.path.abspath(os.path.dirname(__file__)),
            os.path.dirname(os.path.dirname(__file__)+os.sep+C),
        ]

        assert resx == res
        pass

if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import
from __future__ import print_function
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects
import pysourceinfo.PySourceInfo

#
#######################
#


class CallUnits(unittest.TestCase):
    
    def testCase000(self):

        plistRaw = [
            os.path.normpath("/a0/b/c"),
            os.path.normpath("/a1/b/c"+os.pathsep+"/a11/b"+os.pathsep+"/a1/b/c"+os.pathsep+"/a11/b"+os.pathsep+"/a1/b/c"+os.pathsep+"/a11/b"+os.pathsep+"/a1/b/c"+os.pathsep+"/a11/b"),
            os.path.normpath("/a2/b/c"),
            os.path.normpath("/a0/b/c"),
            os.path.normpath("/a1/b/c"+os.pathsep+"/a0/b/c"+os.pathsep+"/a11/b"),
            os.path.normpath("/a2/b/c"),
        ]        
        plist = plistRaw[:]
        
        filesysobjects.FileSysObjects.clearPath(plist,**{'redundant':True,'shrink':True,'split':True,}) # here just a demo
        plistRef = [
            os.path.normpath('/a0/b/c'), 
            os.path.normpath('/a1/b/c'), 
            os.path.normpath('/a11/b'), 
            os.path.normpath('/a2/b/c')
        ]

        assert plist == plistRef

        pass


#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Get the caller name.
"""
from __future__ import absolute_import
from __future__ import print_function

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects
import pysourceinfo

#
#######################
#


class CallUnits(unittest.TestCase):

    def root_from_string(self):
        _s = sys.path[:]
        #
        # prefix from unchanged sys.path
        mySysPathPrefixRaw = pysourceinfo.PySourceInfo.getPythonPathFromSysPath(__file__)
        
        myTestPath0 = os.sep+'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'+os.sep+'e'+os.sep+'f'+os.sep+'g'+os.sep+'h'
        myTestPath1 = myTestPath0 + myTestPath0
        myTestPath2 = myTestPath1 + myTestPath0 #@UnusedVariable
        
        #
        # set search for the call of 'myscript.sh'
        from filesysobjects.FileSysObjects import setUpperTreeSearchPath
        setUpperTreeSearchPath(None,'UseCases'+os.sep)


        px = filesysobjects.FileSysObjects.getTopFromPathString(
            'd'+os.sep,[myTestPath1]
        )

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        pxn = os.sep+'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'
        assert pxn == px
        pass

    def root_from_string_matchlvl0(self):
        _s = sys.path[:]
        #
        # prefix from unchanged sys.path
        mySysPathPrefixRaw = pysourceinfo.PySourceInfo.getPythonPathFromSysPath(__file__)
        
        myTestPath0 = os.sep+'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'+os.sep+'e'+os.sep+'f'+os.sep+'g'+os.sep+'h'
        myTestPath1 = myTestPath0 + myTestPath0
        myTestPath2 = myTestPath1 + myTestPath0
        
        #
        # set search for the call of 'myscript.sh'
        from filesysobjects.FileSysObjects import setUpperTreeSearchPath
        setUpperTreeSearchPath(None,'UseCases'+os.sep)

        px = filesysobjects.FileSysObjects.getTopFromPathString(
            'd'+os.sep,[myTestPath1],**{'matchlvl':0}
        )

        pxn = os.sep+'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        
        assert pxn == px
        pass

    def root_from_string_matchlvl1(self):
        _s = sys.path[:]
        #
        # prefix from unchanged sys.path
        mySysPathPrefixRaw = pysourceinfo.PySourceInfo.getPythonPathFromSysPath(__file__)
        
        myTestPath0 = os.sep+'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'+os.sep+'e'+os.sep+'f'+os.sep+'g'+os.sep+'h'
        myTestPath1 = myTestPath0 + myTestPath0
        myTestPath2 = myTestPath1 + myTestPath0 #@UnusedVariable
        
        #
        # set search for the call of 'myscript.sh'
        from filesysobjects.FileSysObjects import setUpperTreeSearchPath
        setUpperTreeSearchPath(None,os.sep+'UseCases'+os.sep)

        px = filesysobjects.FileSysObjects.getTopFromPathString(
            'd'+os.sep,[myTestPath1],**{'matchlvl':1}
        )

        pxn = myTestPath0 +os.sep+ 'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        
        assert pxn == px
        pass

    def testCase003(self):
        _s = sys.path[:]
        #
        # prefix from unchanged sys.path
        mySysPathPrefixRaw = pysourceinfo.PySourceInfo.getPythonPathFromSysPath(__file__)
        
        myTestPath0 = os.sep+'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'+os.sep+'e'+os.sep+'f'+os.sep+'g'+os.sep+'h'
        myTestPath1 = myTestPath0 + myTestPath0
        myTestPath2 = myTestPath1 + myTestPath0
        
        #
        # set search for the call of 'myscript.sh'
        from filesysobjects.FileSysObjects import setUpperTreeSearchPath
        setUpperTreeSearchPath(os.path.abspath(os.path.dirname(__file__)),'UseCases'+os.sep)

        px = filesysobjects.FileSysObjects.getTopFromPathString(
            'd'+os.sep,[myTestPath2],**{'matchlvl':2}
        )

        pxn = myTestPath1 +os.sep+ 'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        
        assert pxn == px
        pass

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest

import filesysobjects.FileSysObjects

#
#######################
#


class CheckNormpathX(unittest.TestCase):

    def __init__(self,*args,**kargs):
        self.printit = False
        super(CheckNormpathX,self).__init__(*args,**kargs)

    def check_normpathX(self,_in,_norm,ty=None):
        if self.printit:
            print 'Test:'
        l0 = len(_in)
        l1 = len(_norm)

        ret0 = filesysobjects.FileSysObjects.normpathX(_in,**{'tpf':ty})
        lr0 = len(ret0)
        if self.printit:
            print "#---l0 ="+str(l0)
            print "#---lr0="+str(lr0)
            print '  _in = "'+ str(_in) +'"'
            for s in _in: print str(s)+" = "+ str(id(s)) + " ord(" + str(ord(s)) + ")  " + str(s)
            print "#---"
            print '  ret0 = "'+ str(ret0) +'"'
            for s in ret0: print str(s)+" = "+ str(id(s)) + " ord(" + str(ord(s)) + ")  " + str(s)
            print "#---"
        self.assertEqual(_norm, ret0) 




"""Check IEEE1003.1-Chap. 4.2.
"""
from __future__ import absolute_import

import unittest
import os

from filesysobjects.PySourceInfo import getPythonPathModuleRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath


#
#######################
#
class CallUnits(unittest.TestCase):
    name=os.path.curdir+__file__

    output=True
    output=False

    def testCase000(self):
        start = 'file://'+str(os.path.dirname(__file__))
        top = 'tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable
        
        import sys
        forDebugOnly = sys.path
        
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathModuleRel(_res[i])) 
        resx = [
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case020', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath', 
            '30_libs/030_FileSysObjects', 
            '30_libs',
            ''
        ]                

        assert resx == res
        pass

    def testCase001(self):
        start = 'file://'+str(os.path.dirname(__file__))
        top = 'tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'reverse':True}) #@UnusedVariable
        
        import sys
        forDebugOnly = sys.path
        
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathModuleRel(_res[i])) 
        resx = [
            '',
            '30_libs', 
            '30_libs/030_FileSysObjects', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case020', 
        ]                

        assert resx == res
        pass

    def testCase010(self):
        start = 'file://'+str(os.path.dirname(__file__))
        top = 'file://tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable
        
        import sys
        forDebugOnly = sys.path
        
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathModuleRel(_res[i])) 
        resx = [
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case020', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath', 
            '30_libs/030_FileSysObjects', 
            '30_libs', 
            ''
        ]

        assert resx == res
        pass

    def testCase011(self):
        start = 'file://'+str(os.path.dirname(__file__))
        top = 'file://tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'reverse':True}) #@UnusedVariable
        
        import sys
        forDebugOnly = sys.path
        
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathModuleRel(_res[i])) 
        resx = [
            '',
            '30_libs', '30_libs/030_FileSysObjects', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case020', 
        ]

        assert resx == res
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import
from __future__ import print_function
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects
import pysourceinfo.PySourceInfo

#
#######################
#


class CallUnits(unittest.TestCase):
    
    def testCase000(self):

        plistRaw = [
            "/a0/b/c",
            "/a0/b/c",
        ]        
        plist = map(os.path.normpath, plistRaw)
        
        filesysobjects.FileSysObjects.clearPath(plist,**{'redundant':True,'shrink':True,}) # here just a demo
        plistRef = [
            "/a0/b/c",
        ]
        plistRef = map(os.path.normpath, plistRef)

        assert plist == plistRef
        pass

#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys #@UnusedImport

from filesysobjects.FileSysObjects import  escapeFilePath,unescapeFilePath


#
#######################
#


class CallUnits(unittest.TestCase):

    def testCase000(self):
        apstr = 'a\b\c'
        apstrRef = 'a\\\\b\\\\c'
        ret = escapeFilePath(apstr,'k')
        self.assertEqual(apstrRef,ret) 
        
        apstrRaw = r'a\b\c' # avoids interpretation by re itself of '\b'
        ret0 = unescapeFilePath(ret)
        self.assertEqual(ret0,apstrRaw) 

    def testCase001(self):
        apstr = 'a\b\c'
        apstrRef = 'a\\\\b\\\\c'
        ret = escapeFilePath(apstr,'k')
        self.assertEqual(apstrRef,ret) 

        apstrRaw = r'a\b\c' # avoids interpretation by re itself of '\b'
        ret0 = unescapeFilePath(ret)
        self.assertEqual(ret0,apstrRaw) 

        
    def testCase002(self):
        apstr = 'a\b\c'
        apstrRef = r'a\b\c'
        
        ret = escapeFilePath(apstr,'k')
        ret = unescapeFilePath(ret)
        self.assertEqual(apstrRef,ret) 

    def testCase010(self):
        apstr = '/a/b/c'
        ret = escapeFilePath(apstr,'k')
        ret = unescapeFilePath(ret)
        self.assertEqual(apstr, ret) 

    def testCase020(self):
        apstr = 'a'
        ret = escapeFilePath(apstr)
        ret = unescapeFilePath(ret)
        self.assertEqual(apstr, ret) 

    def testCase030(self):
        apstr = '/'
        ret = escapeFilePath(apstr,'k')
        ret = unescapeFilePath(ret)
        self.assertEqual(apstr, ret) 

    def testCase035(self):
        apstr = '\\'
        ret = escapeFilePath(apstr,'k')
        ret = unescapeFilePath(ret)
        self.assertEqual(apstr, ret) 

    def testCase040(self):
        apstr = ''
        ret = escapeFilePath(apstr,'k')
        ret = unescapeFilePath(ret)
        self.assertEqual(apstr, ret) 

#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Check IEEE1003.1-Chap. 4.2.
"""
from __future__ import absolute_import

import unittest
import os

from filesysobjects.PySourceInfo import getPythonPathModuleRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath


#
#######################
#
class CallUnits(unittest.TestCase):
    name=os.path.curdir+__file__

    output=True
    output=False

    def testCase000(self):
        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        start = 'file://'+str(os.path.dirname(__file__))+os.sep+D
        top = 'file://a/b'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable
        
        import sys
        forDebugOnly = sys.path
        
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathModuleRel(_res[i])) 
        resx = [
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b/c/d', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b/c', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b'
        ]

        assert resx == res
        pass

    def testCase001(self):
        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        start = 'file://'+str(os.path.dirname(__file__))+os.sep+D
        top = 'file:///a/b'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        import sys
        forDebugOnly = sys.path
        
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathModuleRel(_res[i])) 
        resx = [
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b/c/d', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b/c', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b'
        ]

        assert resx == res
        pass

    def testCase010(self):
        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        start = 'file://'+str(os.path.dirname(__file__))+os.sep+D
        top = 'file:////a/b'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        import sys
        forDebugOnly = sys.path
        
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathModuleRel(_res[i])) 
        resx = [
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b/c/d', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b/c', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b'
        ]

        assert resx == res
        pass

    def testCase011(self):
        A = 'a/A.txt'         #@UnusedVariable
        B = 'a/b/B.txt'       #@UnusedVariable
        C = 'a/b/c/C.txt'     #@UnusedVariable
        D = 'a/b/c/d/D.txt'   #@UnusedVariable

        start = 'file://'+str(os.path.dirname(__file__))+os.sep+D
        top = 'file://///a/b'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        import sys
        forDebugOnly = sys.path
        
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathModuleRel(_res[i])) 
        resx = [
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b/c/d', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b/c', 
            '30_libs/030_FileSysObjects/010_setUpperTreeSearchPath/110_uri/Case030/a/b'
        ]

        assert resx == res
        pass


if __name__ == '__main__':
    unittest.main()



"""Check IEEE1003.1-Chap. 4.2.
"""
from __future__ import absolute_import

import unittest
import os,sys
import platform

from pysourceinfo.PySourceInfo import getPythonPathRel,getPythonPathFromSysPath
from filesysobjects.FileSysObjects import setUpperTreeSearchPath,FileSysObjectsException,splitAppPrefix,getAppPrefixLocalPath,getTopFromPathString,unescapeFilePath
from unittest.case import SkipTest


#
#######################
#
class CallUnits(unittest.TestCase):
    
    def testCase_drive_and_file(self):
        _s = sys.path[:]
        start = os.path.abspath(os.path.dirname(__file__)+os.path.normpath('/a/b/c'))
        top = os.path.dirname(__file__)
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        myplist = [getTopFromPathString('FileSysObjects',[os.path.dirname(__file__)+os.sep+start])]
        res = []
        for i in range(len(_res)):
            _p = getPythonPathRel(_res[i],myplist)
            if _p:
                res.append(_p) 
        resx = [
            'AppPathSyntax/win_drive/drive_and_file/a/b/c',
            'AppPathSyntax/win_drive/drive_and_file/a/b',
            'AppPathSyntax/win_drive/drive_and_file/a',
            'AppPathSyntax/win_drive/drive_and_file',
        ]        
        resx = map(os.path.normpath,resx)

        res = map(unescapeFilePath, res)
        resx = map(unescapeFilePath, resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass

    def testCase_drive_and_file2(self):

        _s = sys.path[:]
        
        start0 = os.path.abspath(os.path.dirname(__file__)+os.sep+os.path.normpath('/a/b/c'))
        d,p = os.path.splitdrive(start0)
        start1 = os.sep + p
    
        # normalize
        _start_elems = splitAppPrefix(start0,**{'ias':True})
        start= getAppPrefixLocalPath(_start_elems)

        assert start0 == start
        
        top = 'AppPathSyntax/'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        myplist = [getTopFromPathString('AppPathSyntax',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 
        resx = [
            'win_drive/drive_and_file/a/b/c',
            'win_drive/drive_and_file/a/b',
            'win_drive/drive_and_file/a',
            'win_drive/drive_and_file',
            'win_drive',
            '.',
        ]        
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os,sys

#from pysourceinfo.PySourceInfo import getPythonPathRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath#,FileSysObjectsException


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase000(self):
        _s = sys.path[:]
        start = os.path.dirname(__file__)+os.sep+'a/tests/a/b/tests/c/d/tests/b/c'
        start = os.path.abspath(start)
        top = 'tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvlupward':0,'relonly':True,'ias':True}) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        resx = [
            'b/c',
            'b'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == _res
        pass

    def testCase001(self):
        _s = sys.path[:]
        start = os.path.dirname(__file__)+os.sep+'a/tests/a/b/tests/c/d/tests/b/c'
        start = os.path.abspath(start)
        
        top = 'tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvlupward':1,'relonly':True,'ias':True}) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        resx = [
            'c/d/tests/b/c', 
            'c/d/tests/b', 
            'c/d/tests', 
            'c/d', 
            'c'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
                
        assert resx == _res
        pass

    def testCase002(self):
        _s = sys.path[:]
        start = os.path.dirname(__file__)+os.sep+'a/tests/a/b/tests/c/d/tests/b/c'
        start = os.path.abspath(start)
        
        top = 'tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvlupward':2,'relonly':True,'ias':True}) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        resx = [
            'a/b/tests/c/d/tests/b/c', 
            'a/b/tests/c/d/tests/b', 
            'a/b/tests/c/d/tests', 
            'a/b/tests/c/d', 
            'a/b/tests/c', 
            'a/b/tests', 
            'a/b', 
            'a'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
               
        assert resx == _res
        pass

    def testCase003(self):
        _s = sys.path[:]
        start = os.path.dirname(__file__)+os.sep+'a/tests/a/b/tests/c/d/tests/b/c'
        start = os.path.abspath(start)

        top = 'tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvlupward':3,'relonly':True,'ias':True}) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        resx = [
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests/a/b/tests/c/d/tests/b/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests/a/b/tests/c/d/tests/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests/a/b/tests/c/d/tests', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests/a/b/tests/c/d', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests/a/b/tests/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests/a/b/tests', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests/a/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests/a', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a/tests', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030/a', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly/Case030', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/240_relonly', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath', 
            '30_libs/040_FileSysObjects', 
            '30_libs'
        ]
        resx = map(os.path.normpath,resx)
        
        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
                
        assert resx == _res
        pass

if __name__ == '__main__':
    unittest.main()
